@@ -2,9 +2,20 @@
 use POE;
 use POE::Component::MessageQueue;
 use POE::Component::MessageQueue::Storage::FileSystem;
+use POE::Component::MessageQueue::Storage::Throttled;
+use POE::Component::MessageQueue::Storage::DBI;
 use POE::Component::MessageQueue::Logger;
+use Getopt::Long;
+use Carp;
 use strict;
 
+$SIG{__DIE__} = sub {
+    Carp::confess(@_);
+};
+
+#use POE::Component::DebugShell;
+#POE::Component::DebugShell->spawn();
+
 # Force some logger output without using the real logger.
 $POE::Component::MessageQueue::Logger::LEVEL = 0;
 
@@ -21,6 +32,16 @@ my $DB_DSN      = "DBI:SQLite:dbname=$DB_FILE";
 my $DB_USERNAME = "";
 my $DB_PASSWORD = "";
 
+my $port     = 61613;
+my $hostname = undef;
+my $throttle_max = 2;
+
+GetOptions(
+	"port|p=i"     => \$port,
+	"hostname|h=s" => \$hostname,
+	"throttle|T=i" => \$throttle_max,
+);
+
 sub _init_sqlite
 {
 	my $DB_CREATE = << "EOF";
@@ -46,11 +67,19 @@ mkdir $DATA_DIR unless ( -d $DATA_DIR );
 _init_sqlite    unless ( -f $DB_FILE );
 
 POE::Component::MessageQueue->new({
-	storage => POE::Component::MessageQueue::Storage::FileSystem->new({
-		dsn      => $DB_DSN,
-		username => $DB_USERNAME,
-		password => $DB_PASSWORD,
-		data_dir => $DATA_DIR,
+	port     => $port,
+	hostname => $hostname,
+
+	storage => POE::Component::MessageQueue::Storage::Throttled->new({
+		storage => POE::Component::MessageQueue::Storage::FileSystem->new({
+			info_storage => POE::Component::MessageQueue::Storage::DBI->new({
+				dsn      => $DB_DSN,
+				username => $DB_USERNAME,
+				password => $DB_PASSWORD,
+			}),
+			data_dir => $DATA_DIR,
+		}),
+		throttle_max => $throttle_max
 	})
 });
 
