@@ -2,8 +2,13 @@
 use POE;
 use POE::Component::Server::Stomp;
 use Net::Stomp::Frame;
+use Carp;
 use strict;
 
+$SIG{__DIE__} = sub {
+    Carp::confess(@_);
+};
+
 POE::Component::Server::Stomp->new(
 	HandleFrame        => \&handle_frame,
 	ClientDisconnected => \&client_disconnected,
