@@ -23,20 +23,37 @@ sub new
 	my $args  = shift;
 
 	my $logger_alias;
+	my $log_function;
 
 	if ( ref($args) eq 'HASH' )
 	{
 		$logger_alias = $args->{logger_alias};
+		$log_function = $args->{log_function};
 	}
 
 	my $self = {
-		logger_alias => $logger_alias
+		logger_alias => $logger_alias,
+		log_function => $log_function,
 	};
 
 	bless  $self, $class;
 	return $self;
 }
 
+sub set_log_function
+{
+	my ($self, $func) = @_;
+	$self->{log_function} = $func;
+	undef;
+}
+
+sub set_logger_alias
+{
+	my ($self, $alias) = @_;
+	$self->{logger_alias} = $alias;
+	undef;
+}
+
 sub log
 {
 	my $self = shift;
@@ -49,7 +66,11 @@ sub log
 		$type = 'info';
 	}
 
-	if ( defined $self->{logger_alias} )
+	if ( defined $self->{log_function} )
+	{
+		$self->{log_function}->( $type, $msg );
+	}
+	elsif ( defined $self->{logger_alias} )
 	{
 		$poe_kernel->post( $self->{logger_alias}, $type, "$msg\n" );
 	}
